"""
 _____     _         _     _     _ _                          
|__  /__ _| | ____ _| |_  | |   (_) |__  _ __ __ _ _ __ _   _ 
  / // _` | |/ / _` | __| | |   | | '_ \| '__/ _` | '__| | | |
 / /| (_| |   < (_| | |_  | |___| | |_) | | | (_| | |  | |_| |
/____\__,_|_|\_\__,_|\__| |_____|_|_.__/|_|  \__,_|_|   \__, |
                                                        |___/ 

"رَبَّنَا افْتَحْ بَيْنَنَا وَبَيْنَ قَوْمِنَا بِالْحَقِّ وَأَنتَ خَيْرُ الْفَاتِحِينَ (89)" -- سورة الأعراف
... Never Trust, Always Verify ...

This file provides the ZakatLibrary classes, functions for tracking and calculating Zakat.
"""
# Importing necessary classes and functions from the main module
from zakat.zakat_tracker import (
    ZakatTracker,
    test,
    Action,
    JSONEncoder,
    MathOperation,
)

from zakat.file_server import (
    start_file_server,
    find_available_port,
    FileType,
)

# Version information for the module
__version__ = ZakatTracker.Version()
__all__ = [
    "ZakatTracker",
    "test",
    "Action",
    "JSONEncoder",
    "MathOperation",
    "start_file_server",
    "find_available_port",
    "FileType",
]



from setuptools import find_packages, setup

setup(
    name='zakat',
    version='0.2.9',
    description='A Python Library for Islamic Financial Management.',
    author='Abdelaziz Elrashed Elshaikh Mohamed',
    author_email='aeemh.sdn@gmail.com',
    classifiers = [
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires=">=3.10",
    packages=find_packages(
        include=[
            'zakat',
        ],
    ),
    requires=[
        'camelx',
    ],
)